@@ -1,19 +1,19 @@
 from __future__ import annotations
 
+from collections.abc import Callable
 from pathlib import Path
-from typing import Any, Callable, Literal, Union, get_type_hints
+from typing import Any, Literal, get_type_hints
 
 import numpy as np
 import pandas
-from dask import delayed
 import plotly.graph_objects as go
-
+from dask import delayed
 
 from pointcloudset.dataset_core import DatasetCore
 from pointcloudset.io import DATASET_FROM_FILE, DATASET_FROM_INSTANCE, DATASET_TO_FILE
 from pointcloudset.pipeline.delayed_result import DelayedResult
-from pointcloudset.pointcloud import PointCloud
 from pointcloudset.plot.dataset import animate_dataset
+from pointcloudset.pointcloud import PointCloud
 
 
 def _is_pipline_returing_pointcloud(pipeline, warn=True) -> bool:
@@ -39,9 +39,7 @@ class Dataset(DatasetCore):
     section of the docu.
     """
 
-    def __getitem__(
-        self, pointcloud_number: Union[slice, int]
-    ) -> Union[DatasetCore, PointCloud]:
+    def __getitem__(self, pointcloud_number: slice | int) -> DatasetCore | PointCloud:
         if isinstance(pointcloud_number, slice):
             data = self.data[pointcloud_number]
             timestamps = self.timestamps[pointcloud_number]
@@ -54,13 +52,13 @@ class Dataset(DatasetCore):
                 data=df, orig_file=self.meta["orig_file"], timestamp=timestamp
             )
         else:
-            raise TypeError("Wrong type {}".format(type(pointcloud_number).__name__))
+            raise TypeError(f"Wrong type {type(pointcloud_number).__name__}")
 
     @classmethod
     def from_file(cls, file_path: Path, **kwargs):
-        """Reads a Dataset from a file.
-        For larger ROS bagfiles files use the commandline tool pointcloudset-convert to convert the ROS bagfile
-        beforehand.
+        """Reads a Dataset from a file.gfile
+        For larger ROS bagfiles files use the commandline tool pointcloudset to convert
+        the ROS file beforehand.
 
         Supported are the native format which is a directore filled with fastparquet frames and
         ROS bag files (.bag).
@@ -79,6 +77,12 @@ class Dataset(DatasetCore):
             ValueError: If file format is not supported.
             TypeError: If file_path is not a Path object.
 
+        Examples:
+
+            .. code-block:: python
+
+                pointcloudset.Dataset.from_file(bag_file, topic="lidar/points", keep_zeros=False)
+
         Examples:
 
             .. code-block:: python
@@ -86,6 +90,7 @@ class Dataset(DatasetCore):
                 pointcloudset.Dataset.from_file(bag_file, topic="lidar/points", keep_zeros=False)
         """
         from_dir = False
+        from_dir = False
         if not isinstance(file_path, Path):
             raise TypeError("Expecting a Path object for file_path")
         ext = file_path.suffix[1:].upper()
@@ -94,7 +99,11 @@ class Dataset(DatasetCore):
                 from_dir = True
                 ext = "DIR"  # native pointcloudset format
             else:
-                ext = "ROS2"  # ROS2 is also a directory
+                ext = "ROS2"  # ROS2 is also a directory for both mcap and dp3
+                if not file_path.joinpath("metadata.yaml").exists():
+                    raise FileNotFoundError(
+                        "metadata.yaml not found in directory, which is required for ROS2 format"
+                    )
         if ext not in DATASET_FROM_FILE:
             raise ValueError(
                 (
@@ -162,10 +171,10 @@ class Dataset(DatasetCore):
 
     def apply(
         self,
-        func: Union[Callable[[PointCloud], PointCloud], Callable[[PointCloud], Any]],
+        func: Callable[[PointCloud], PointCloud] | Callable[[PointCloud], Any],
         warn: bool = True,
         **kwargs,
-    ) -> Union[Dataset, DelayedResult]:
+    ) -> Dataset | DelayedResult:
         """Applies a function to the dataset. It is also possible to pass keyword
         arguments.
 
@@ -205,9 +214,7 @@ class Dataset(DatasetCore):
 
                 dataset.apply(func, test=10)
         """
-
         returns_pointcloud = _is_pipline_returing_pointcloud(func, warn=warn)
-
         columns = list(self[0].data.columns)
 
         if returns_pointcloud:
@@ -250,7 +257,7 @@ class Dataset(DatasetCore):
 
     def agg(
         self,
-        agg: Union[str, list, dict],
+        agg: str | list | dict,
         depth: Literal["dataset", "pointcloud", "point"] = "dataset",
     ) -> Union[
         pandas.Series, list[pandas.DataFrame], pandas.DataFrame, pandas.DataFrame
@@ -470,9 +477,9 @@ class Dataset(DatasetCore):
         return self.agg("std", depth=depth)
 
     def _agg_per_pointcloud(
-        self, agg: Union[str, list, dict]
-    ) -> Union[pandas.DataFrame, list, pandas.DataFrame]:
-        def get(pointcloud, agg: Union[str, list, dict]):
+        self, agg: str | list | dict
+    ) -> pandas.DataFrame | list | pandas.DataFrame:
+        def get(pointcloud, agg: str | list | dict):
             return pointcloud.data.agg(agg)
 
         res = self.apply(get, warn=False, agg=agg).compute()
