@@ -2,8 +2,11 @@
 Utiliy functions for filtering of frames.
 """
 
-from pointcloudset.filter.stat import (quantile_filter, remove_radius_outlier,
-                                       value_filter)
+from pointcloudset.filter.stat import (
+    quantile_filter,
+    remove_radius_outlier,
+    value_filter,
+)
 
 ALL_FILTERS = {
     "QUANTILE": quantile_filter,
