@@ -1,7 +1,7 @@
 from __future__ import annotations
 
 from collections import UserList
-from typing import Any, Union
+from typing import Any
 
 import dask
 
@@ -13,10 +13,8 @@ class DelayedResult(UserList):
     def compute(self) -> list:
         return list(dask.compute(*self.data))
 
-    def __getitem__(
-        self, pointcloud_number: Union[slice, int]
-    ) -> Union[DelayedResult, Any]:
+    def __getitem__(self, pointcloud_number: slice | int) -> DelayedResult | Any:
         if isinstance(pointcloud_number, (slice, int)):
             return super().__getitem__(pointcloud_number).compute()
         else:
-            raise TypeError("Wrong type {}".format(type(pointcloud_number).__name__))
+            raise TypeError(f"Wrong type {type(pointcloud_number).__name__}")
